@@ -1,9 +1,11 @@
 use std::{env, fs};
 use rust_utils::utils;
+
 mod tui;
 mod cli;
 mod bible;
 mod config;
+mod obi_search;
 
 fn main() {
     // get the command line arguments of the program
@@ -15,14 +17,14 @@ fn main() {
     else {
         arg = args[1].to_string();
     }
-    if utils::get_execname()=="bible"{
+    if utils::get_execname() == "bible" {
         args.remove(0);
         cli::parse_args(args);
     }
 
     // start the TUI
-    else if utils::get_execname()=="the_rock"{
-        tui::show_ui(arg);
+    else if utils::get_execname() == "the_rock" {
+        tui::init(arg);
     }
 
     // file cleanup
